==> flink-1.16.2-src.tgz: flink-1.16.2/flink-streaming-java/src/main/java/org/apache/flink/streaming/api/operators/source/TimestampsAndWatermarksContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.streaming.api.operators.source;

import org.apache.flink.annotation.Internal;
import org.apache.flink.api.common.eventtime.TimestampAssignerSupplier;
import org.apache.flink.api.common.eventtime.WatermarkGeneratorSupplier;
import org.apache.flink.metrics.MetricGroup;

import static org.apache.flink.util.Preconditions.checkNotNull;

/**
 * A simple implementation of a context that is both {@link TimestampAssignerSupplier.Context} and
 * {@link WatermarkGeneratorSupplier.Context}.
 */
@Internal
public final class TimestampsAndWatermarksContext
        implements TimestampAssignerSupplier.Context, WatermarkGeneratorSupplier.Context {

    private final MetricGroup metricGroup;

    public TimestampsAndWatermarksContext(MetricGroup metricGroup) {
        this.metricGroup = checkNotNull(metricGroup);
    }

    @Override
    public MetricGroup getMetricGroup() {
        return metricGroup;
    }
}

==> flink-1.20.2-src.tgz: flink-1.20.2/flink-streaming-java/src/main/java/org/apache/flink/streaming/api/operators/source/TimestampsAndWatermarksContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.streaming.api.operators.source;

import org.apache.flink.annotation.Internal;
import org.apache.flink.api.common.eventtime.TimestampAssignerSupplier;
import org.apache.flink.api.common.eventtime.WatermarkGeneratorSupplier;
import org.apache.flink.metrics.MetricGroup;
import org.apache.flink.util.clock.RelativeClock;

import static org.apache.flink.util.Preconditions.checkNotNull;

/**
 * A simple implementation of a context that is both {@link TimestampAssignerSupplier.Context} and
 * {@link WatermarkGeneratorSupplier.Context}.
 */
@Internal
public final class TimestampsAndWatermarksContext
        implements TimestampAssignerSupplier.Context, WatermarkGeneratorSupplier.Context {

    private final MetricGroup metricGroup;
    private final RelativeClock inputActivityClock;

    public TimestampsAndWatermarksContext(
            MetricGroup metricGroup, RelativeClock inputActivityClock) {
        this.metricGroup = checkNotNull(metricGroup);
        this.inputActivityClock = inputActivityClock;
    }

    @Override
    public MetricGroup getMetricGroup() {
        return metricGroup;
    }

    @Override
    public RelativeClock getInputActivityClock() {
        return inputActivityClock;
    }
}
